# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('aldryn_categories', '0002_auto_20150109_1415'),
    ]

    operations = [
        migrations.AlterField(
            model_name='categorytranslation',
            name='language_code',
            field=models.CharField(db_index=True, max_length=15, verbose_name='Language', choices=[(b'en', b'English'), (b'de', b'German'), (b'fr', b'French')]),
            preserve_default=True,
        ),
        migrations.AlterUniqueTogether(
            name='categorytranslation',
            unique_together=set([('language_code', 'master'), ('language_code', 'slug')]),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('aldryn_categories', '0003_auto_20150128_1359'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='categorytranslation',
            options={'default_permissions': (), 'verbose_name': 'category Translation', 'managed': True},
        ),
        migrations.AlterField(
            model_name='categorytranslation',
            name='language_code',
            field=models.CharField(max_length=15, verbose_name='Language', db_index=True),
            preserve_default=True,
        ),
    ]



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.core.exceptions import ImproperlyConfigured
from django.test import TestCase

from parler.utils.context import switch_language

from aldryn_categories.models import Category
from aldryn_categories.fields import (
    CategoryForeignKey,
    CategoryManyToManyField,
    CategoryModelChoiceField,
    CategoryMultipleChoiceField,
    CategoryOneToOneField,
)

from .base import CategoryTestCaseMixin


class TestCategoryField(CategoryTestCaseMixin, TestCase):

    def test_category_model_choice_field(self):
        root = Category.add_root(name="root")
        root.save()
        child1 = root.add_child(name="child1")
        child2 = root.add_child(name="child2")
        grandchild1 = child1.add_child(name="grandchild1")
        bad_grandchild = child1.add_child(
            name='bad grandchild<script>alert("bad stuff");</script>')
        field = CategoryModelChoiceField(None)

        self.assertEqual(
            field.label_from_instance(child2),
            "&nbsp;&nbsp;child2",
        )
        self.assertEqual(
            field.label_from_instance(grandchild1),
            "&nbsp;&nbsp;&nbsp;&nbsp;grandchild1",
        )
        self.assertEqual(
            field.label_from_instance(bad_grandchild),
            '&nbsp;&nbsp;&nbsp;&nbsp;bad grandchild&lt;script&gt;alert'
            '(&quot;bad stuff&quot;);&lt;/script&gt;',
        )

        # Tests that the field correctly throws an ImproperlyConfigured
        # exception if the given object is not a Category (or something that
        # acts like one)
        with self.assertRaises(ImproperlyConfigured):
            field.label_from_instance(object)

        # Check that using an untranslated language does not raise exceptions
        with switch_language(child1, 'it'):
            try:
                field.label_from_instance(child1)
            except ImproperlyConfigured:
                self.fail("Translating to an unavailable language should not "
                          "result in an exception.")

    def test_category_multiple_choice_field(self):
        root = Category.add_root(name="root")
        root.save()
        child1 = root.add_child(name="child1")
        child2 = root.add_child(name="child2")
        grandchild1 = child1.add_child(name="grandchild1")
        bad_grandchild = child1.add_child(
            name='bad grandchild<script>alert("bad stuff");</script>')
        root = self.reload(root)
        child1 = self.reload(child1)
        field = CategoryMultipleChoiceField(None)
        self.assertEqual(
            field.label_from_instance(child2),
            "&nbsp;&nbsp;child2",
        )
        self.assertEqual(
            field.label_from_instance(grandchild1),
            "&nbsp;&nbsp;&nbsp;&nbsp;grandchild1",
        )
        self.assertEqual(
            field.label_from_instance(bad_grandchild),
            '&nbsp;&nbsp;&nbsp;&nbsp;bad grandchild&lt;script&gt;alert'
            '(&quot;bad stuff&quot;);&lt;/script&gt;',
        )

        # Tests that the field correctly throws an ImproperlyConfigured
        # exception if the given object is not a Category (or something that
        # acts like one)
        with self.assertRaises(ImproperlyConfigured):
            field.label_from_instance(object)

        # Check that using an untranslated language does not raise exceptions
        with switch_language(child1, 'it'):
            try:
                field.label_from_instance(child1)
            except ImproperlyConfigured:
                self.fail("Translating to an unavailable language should not "
                          "result in an exception.")

    def test_category_fk_field(self):
        field = CategoryForeignKey(Category)
        form_field = field.formfield()
        self.assertTrue(isinstance(form_field, CategoryModelChoiceField))
        field_type = field.get_internal_type()
        self.assertEquals(field_type, 'ForeignKey')

    def test_category_one_to_one_field(self):
        field = CategoryOneToOneField(Category)
        form_field = field.formfield()
        self.assertTrue(isinstance(form_field, CategoryModelChoiceField))
        field_type = field.get_internal_type()
        self.assertEquals(field_type, 'ForeignKey')

    def test_category_many_to_many_field(self):
        field = CategoryManyToManyField(Category)
        form_field = field.formfield()
        self.assertTrue(isinstance(form_field, CategoryMultipleChoiceField))
        field_type = field.get_internal_type()
        self.assertEquals(field_type, 'ManyToManyField')



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.utils.translation import ugettext_lazy as _

from cms.wizards.wizard_pool import wizard_pool
from cms.wizards.wizard_base import Wizard
from cms.wizards.forms import BaseFormMixin

from parler.forms import TranslatableModelForm
from treebeard.forms import movenodeform_factory, MoveNodeForm

from .models import Category


class CategoryWizard(Wizard):

    def get_success_url(self, *args, **kwargs):
        # Since categories do not have their own urls, return None so that
        # cms knows that it should just close the wizard window (reload
        # current page)
        return None


class CreateCategoryForm(BaseFormMixin, TranslatableModelForm, MoveNodeForm):
    """
    The model form for Category wizad.
    """

    class Meta:
        model = Category
        fields = ['name', 'slug', ]


aldryn_category_wizard = CategoryWizard(
    title=_(u"New category"),
    weight=290,
    form=movenodeform_factory(Category, form=CreateCategoryForm),
    description=_(u"Create a new category.")
)

wizard_pool.register(aldryn_category_wizard)
